==> wow-openapi-2.6.0-sources.jar: me/ahoo/wow/openapi/converter/BoundedContextSchemaNameConverter.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.wow.openapi.converter

import com.fasterxml.jackson.databind.JavaType
import io.swagger.v3.core.converter.AnnotatedType
import io.swagger.v3.core.converter.ModelConverter
import io.swagger.v3.core.converter.ModelConverterContext
import io.swagger.v3.oas.models.media.Schema
import me.ahoo.wow.openapi.Schemas.asSchemName

class BoundedContextSchemaNameConverter : ModelConverter {
    override fun resolve(
        type: AnnotatedType,
        context: ModelConverterContext,
        chain: Iterator<ModelConverter>
    ): Schema<*>? {
        if (type.name.isNullOrBlank()) {
            val schemaType = type.type
            if (schemaType is Class<*>) {
                type.name = schemaType.asSchemName()
            }
            if (schemaType is JavaType) {
                type.name = schemaType.rawClass.asSchemName()
            }
        }
        if (chain.hasNext()) {
            return chain.next().resolve(type, context, chain)
        }
        return null
    }
}

==> wow-openapi-2.13.2-sources.jar: me/ahoo/wow/openapi/converter/BoundedContextSchemaNameConverter.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.wow.openapi.converter

import com.fasterxml.jackson.databind.JavaType
import io.swagger.v3.core.converter.AnnotatedType
import io.swagger.v3.core.converter.ModelConverter
import io.swagger.v3.core.converter.ModelConverterContext
import io.swagger.v3.oas.models.media.Schema
import me.ahoo.wow.openapi.SchemaRef.Companion.toSchemaName
import me.ahoo.wow.serialization.JsonSerializer

class BoundedContextSchemaNameConverter : ModelConverter {
    companion object {
        fun AnnotatedType.getRawClass(): Class<*>? {
            val schemaType = this.type
            if (schemaType is Class<*>) {
                return schemaType
            }
            if (schemaType is JavaType) {
                return schemaType.rawClass
            }
            return null
        }

        fun AnnotatedType.getJavaType(): JavaType? {
            val schemaType = this.type
            if (schemaType is JavaType) {
                return schemaType
            }
            if (schemaType is Class<*>) {
                return JsonSerializer.constructType(schemaType)
            }

            return null
        }
    }

    override fun resolve(
        type: AnnotatedType,
        context: ModelConverterContext,
        chain: Iterator<ModelConverter>
    ): Schema<*>? {
        if (type.name.isNullOrBlank()) {
            type.getRawClass()?.let {
                type.name = it.toSchemaName()
            }
        }
        if (chain.hasNext()) {
            return chain.next().resolve(type, context, chain)
        }
        return null
    }
}
